==> byways-1.10.9.tgz: package/contents/byway/10780.md <==
---
template: byway.jade
id: "10780"
name: Black River Scenic Byway
distance: "11"
duration: 30 minutes
description: "Black River Harbor, one of only two harbors within the National Forest System, is a popular recreation area throughout the year.  The harbor is approximately 15 miles north of Bessemer, Michigan, at the mouth of the Black River.  The Black River flows through areas of large pine, hemlock, and hardwood trees and has a series of scenic waterfalls as it drops to meet Lake Superior.  On September 19, 1992, Highway 513, which follows this section of the Black River, was officially dedicated as a National Forest Scenic Byway in recognition of its exceptional beauty and recreational opportunities."
contact: "**Ottawa National Forest**  \r\n*Supervisor's Office*  \r\nPhone: 906-932-1330  \r\nTDD: 906-932-0301"
path: "ya}zG`_|dPkcA_CsGe@}Ak@cBaAaM}HkVmNiDgCo@s@yBqDoNyVyBqCmB_BiC_AgDy@uIy@wM{@qHK{Ow@wHIoPk@mCQgFDo@JmC`AoBlAak@`o@kJ`LoCpBsC`@oGVg`@QaGSu[@_Aj@eDdAy_@|NsElAiC\\}HFaTK_CGaBYuA_@_D_BcByAqB{Bal@y`AuAeBcBmAiC_BuFkAcHaAcFe@aD@oDb@iD`AiLlGmB`@oBJ}B_@q@UgBwA}AyBuAuC_Pq]iGyNo]qu@aCsDyZoXsE{EaEsF}DiCmF_CwEeBeCsBkHgIqJmIiGoE{EkCeOiK_Bk@cBSmWk@oNuAgEEsENuBAw@QoAo@uJ}HyBvCiAlAc@JgBC"
websites: 
  - url: "http://areas.wildernet.com/pages/area.cfm?areaID=BWY10780&CU_ID=165"
    name: Black River Scenic Byway Website
  - url: "http://www.exploringthenorth.com/ottawa/mtbike.html"
    name: Mountain Biking in the Ottowa National Forest
  - url: "http://www.fs.usda.gov/ottawa/"
    name: Ottawa National Forest Homepage
  - url: "http://www.gorp.com/gorp/resource/us_national_forest/mi/drv_ott.htm"
    name: Scenic Driving in Ottawa National Forest
designations: 
  - National Forest Scenic Byway
states: 
  - MI
ll: 
  - -90.0966489999999
  - 46.520779000000005
bounds: 
  - - -90.09742699999998
    - 46.520779000000005
  - - -90.04696699999994
    - 46.66570999999999

---

Black River Harbor, one of only two harbors within the National Forest System, is a popular recreation area throughout the year.  The harbor is approximately 15 miles north of Bessemer, Michigan, at the mouth of the Black River.  The Black River flows through areas of large pine, hemlock, and hardwood trees and has a series of scenic waterfalls as it drops to meet Lake Superior.  On September 19, 1992, Highway 513, which follows this section of the Black River, was officially dedicated as a National Forest Scenic Byway in recognition of its exceptional beauty and recreational opportunities.

==> byways-2.3.2.tgz: package/contents/byway/10780.md <==
---
id: "10780"
name: Black River Scenic Byway
distance: "11"
duration: 30 minutes
description: "Black River Harbor, one of only two harbors within the National Forest System, is a popular recreation area throughout the year.  The harbor is approximately 15 miles north of Bessemer, Michigan, at the mouth of the Black River.  The Black River flows through areas of large pine, hemlock, and hardwood trees and has a series of scenic waterfalls as it drops to meet Lake Superior.  On September 19, 1992, Highway 513, which follows this section of the Black River, was officially dedicated as a National Forest Scenic Byway in recognition of its exceptional beauty and recreational opportunities."
contact: "**Ottawa National Forest**  \r\n*Supervisor's Office*  \r\nPhone: 906-932-1330  \r\nTDD: 906-932-0301"
path: "ya}zG`_|dPkcA_CsGe@}Ak@cBaAaM}HkVmNiDgCo@s@yBqDoNyVyBqCmB_BiC_AgDy@uIy@wM{@qHK{Ow@wHIoPk@mCQgFDo@JmC`AoBlAak@`o@kJ`LoCpBsC`@oGVg`@QaGSu[@_Aj@eDdAy_@|NsElAiC\\}HFaTK_CGaBYuA_@_D_BcByAqB{Bal@y`AuAeBcBmAiC_BuFkAcHaAcFe@aD@oDb@iD`AiLlGmB`@oBJ}B_@q@UgBwA}AyBuAuC_Pq]iGyNo]qu@aCsDyZoXsE{EaEsF}DiCmF_CwEeBeCsBkHgIqJmIiGoE{EkCeOiK_Bk@cBSmWk@oNuAgEEsENuBAw@QoAo@uJ}HyBvCiAlAc@JgBC"
websites:
  - url: "https://en.wikipedia.org/wiki/Black_River_National_Forest_Scenic_Byway"
    name: Black River National Forest Scenic Byway
  - url: "http://areas.wildernet.com/pages/area.cfm?areaID=BWY10780&CU_ID=165"
    name: Black River Scenic Byway Website
  - url: "http://www.exploringthenorth.com/ottawa/mtbike.html"
    name: Mountain Biking in the Ottawa National Forest
  - url: "http://www.fs.usda.gov/ottawa/"
    name: Ottawa National Forest Homepage
designations:
  - National Forest Scenic Byway
states:
  - MI
ll:
  - -90.0966489999999
  - 46.520779000000005
bounds:
  - - -90.09742699999998
    - 46.520779000000005
  - - -90.04696699999994
    - 46.66570999999999

---

Black River Harbor, one of only two harbors within the National Forest System, is a popular recreation area throughout the year.  The harbor is approximately 15 miles north of Bessemer, Michigan, at the mouth of the Black River.  The Black River flows through areas of large pine, hemlock, and hardwood trees and has a series of scenic waterfalls as it drops to meet Lake Superior.  On September 19, 1992, Highway 513, which follows this section of the Black River, was officially dedicated as a National Forest Scenic Byway in recognition of its exceptional beauty and recreational opportunities.
